@@ -1,22 +1,25 @@
+require_relative 'configuration/filter'
 require_relative 'configuration/question'
-require_relative 'configuration/servers'
 require_relative 'configuration/server'
+require_relative 'configuration/servers'
 
 module Capistrano
   class Configuration
 
-    class << self
-      def env
-        @env ||= new
-      end
-
-      def reset!
-        @env = new
-      end
+    def initialize(config = nil)
+      @config ||= config
     end
 
-    def ask(key, default=nil)
-      question = Question.new(self, key, default)
+    def self.env
+      @env ||= new
+    end
+
+    def self.reset!
+      @env = new
+    end
+
+    def ask(key, default=nil, options={})
+      question = Question.new(key, default, options)
       set(key, question)
     end
 
@@ -24,6 +27,10 @@ module Capistrano
       config[key] = value
     end
 
+    def set_if_empty(key, value)
+      config[key] = value unless config.has_key? key
+    end
+
     def delete(key)
       config.delete(key)
     end
@@ -56,6 +63,10 @@ module Capistrano
       servers.roles_for(names)
     end
 
+    def role_properties_for(names, &block)
+      servers.role_properties_for(names, &block)
+    end
+
     def primary(role)
       servers.fetch_primary(role)
     end
@@ -75,7 +86,7 @@ module Capistrano
         sshkit.backend.configure do |backend|
           backend.pty                = fetch(:pty)
           backend.connection_timeout = fetch(:connection_timeout)
-          backend.ssh_options        = fetch(:ssh_options) if fetch(:ssh_options)
+          backend.ssh_options        = (backend.ssh_options || {}).merge(fetch(:ssh_options,{}))
         end
       end
     end
@@ -84,8 +95,30 @@ module Capistrano
       @timestamp ||= Time.now.utc
     end
 
+    def setup_filters
+      @filters = cmdline_filters.clone
+      @filters << Filter.new(:role, ENV['ROLES']) if ENV['ROLES']
+      @filters << Filter.new(:host, ENV['HOSTS']) if ENV['HOSTS']
+      fh = fetch_for(:filter,{})
+      @filters << Filter.new(:host, fh[:host]) if fh[:host]
+      @filters << Filter.new(:role, fh[:role]) if fh[:role]
+    end
+
+    def add_cmdline_filter(type, values)
+      cmdline_filters << Filter.new(type, values)
+    end
+
+    def filter list
+      setup_filters if @filters.nil?
+      @filters.reduce(list) { |l,f| f.filter l }
+    end
+
     private
 
+    def cmdline_filters
+      @cmdline_filters ||= []
+    end
+
     def servers
       @servers ||= Servers.new
     end
